@@ -1,5 +1,6 @@
-def add_numbers(a, b):
+def add_numbers(a: int, b: int) -> int:
     return a + b
 
+
 def subtract_numbers(a, b):
     return a - b
